/*******************************************************************************
* File Name: V5_PM.c
* Version 1.80
*
* Description:
*  This file contains the setup, control, and status commands to support 
*  the component operation in the low power mode. 
*
* Note:
*
********************************************************************************
* Copyright 2015, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#include "V5.h"

/* Check for removal by optimization */
#if !defined(V5_Sync_ctrl_reg__REMOVED)

static V5_BACKUP_STRUCT  V5_backup = {0u};

    
/*******************************************************************************
* Function Name: V5_SaveConfig
********************************************************************************
*
* Summary:
*  Saves the control register value.
*
* Parameters:
*  None
*
* Return:
*  None
*
*******************************************************************************/
void V5_SaveConfig(void) 
{
    V5_backup.controlState = V5_Control;
}


/*******************************************************************************
* Function Name: V5_RestoreConfig
********************************************************************************
*
* Summary:
*  Restores the control register value.
*
* Parameters:
*  None
*
* Return:
*  None
*
*
*******************************************************************************/
void V5_RestoreConfig(void) 
{
     V5_Control = V5_backup.controlState;
}


/*******************************************************************************
* Function Name: V5_Sleep
********************************************************************************
*
* Summary:
*  Prepares the component for entering the low power mode.
*
* Parameters:
*  None
*
* Return:
*  None
*
*******************************************************************************/
void V5_Sleep(void) 
{
    V5_SaveConfig();
}


/*******************************************************************************
* Function Name: V5_Wakeup
********************************************************************************
*
* Summary:
*  Restores the component after waking up from the low power mode.
*
* Parameters:
*  None
*
* Return:
*  None
*
*******************************************************************************/
void V5_Wakeup(void)  
{
    V5_RestoreConfig();
}

#endif /* End check for removal by optimization */


/* [] END OF FILE */
